pub struct CapabilityAction {
pub kind: CapabilityActionKind,
pub summary: String,
pub path: Option<String>,
}Expand description
One action checked, skipped, executed, or failed during a lifecycle run.
Fields
kind: CapabilityActionKindAction kind.
summary: StringShort action summary.
path: Option<String>Project-relative path, when the action concerns a filesystem path.