pub struct Context { /* private fields */ }Expand description
Per-invocation state, constructed from the dispatcher env contract.
Implementations
Sourceimpl Context
impl Context
Sourcepub fn from_env() -> Self
pub fn from_env() -> Self
Construct a Context by reading the documented READY_SET_* env vars.
Tolerates unset and unrecognized values per the env-vars contract.
Sourcepub const fn default_for_tests() -> Self
pub const fn default_for_tests() -> Self
Construct a default Context for tests or programmatic use.
Sourcepub const fn dispatcher_version(&self) -> Option<&Version>
pub const fn dispatcher_version(&self) -> Option<&Version>
Version of the dispatcher that invoked this plugin, if any.
Sourcepub fn project_root(&self) -> Option<&Path>
pub fn project_root(&self) -> Option<&Path>
Resolved project root, if any.
Sourcepub fn config_path(&self) -> Option<&Path>
pub fn config_path(&self) -> Option<&Path>
Resolved .ready-set.toml path, if any.
Sourcepub const fn output_mode(&self) -> OutputMode
pub const fn output_mode(&self) -> OutputMode
Requested output mode.
Sourcepub fn project_root_or_cwd(&self) -> Result<PathBuf>
pub fn project_root_or_cwd(&self) -> Result<PathBuf>
Return Self::project_root if known, otherwise cwd.
Errors
Returns the underlying I/O error from std::env::current_dir if the
current working directory cannot be resolved.